/*
 * Copyright (C) 2008 Till Harbaum <till@harbaum.org>.
 *
 * This file is part of GPXView.
 *
 * GPXView is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * GPXView is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with GPXView.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef HDR_DBUS_H
#define HDR_DBUS_H

extern void dbus_register(appdata_t *appdata);
extern int dbus_mm_set_position(appdata_t *appdata, pos_t *pos);

#ifdef ENABLE_BROWSER_INTERFACE
extern int browser_url(appdata_t *appdata, char *url);
#endif

#endif // HDR_DBUS_H
